@@ -7,7 +7,7 @@ These are necessary to avoid circular imports between core.py and fields.py.
     This module is treated as private API.
     Users should not need to use this module directly.
 """
-import typing
+from __future__ import annotations
 
 
 class FieldABC:
@@ -33,24 +33,22 @@ class FieldABC:
 class SchemaABC:
     """Abstract base class from which all Schemas inherit."""
 
-    def dump(self, obj, *, many: typing.Optional[bool] = None):
+    def dump(self, obj, *, many: bool | None = None):
         raise NotImplementedError
 
-    def dumps(self, obj, *, many: typing.Optional[bool] = None):
+    def dumps(self, obj, *, many: bool | None = None):
         raise NotImplementedError
 
-    def load(
-        self, data, *, many: typing.Optional[bool] = None, partial=None, unknown=None
-    ):
+    def load(self, data, *, many: bool | None = None, partial=None, unknown=None):
         raise NotImplementedError
 
     def loads(
         self,
         json_data,
         *,
-        many: typing.Optional[bool] = None,
+        many: bool | None = None,
         partial=None,
         unknown=None,
-        **kwargs
+        **kwargs,
     ):
         raise NotImplementedError
