@@ -1,4 +1,6 @@
 """The :class:`Schema` class, including its metaclass and options (class Meta)."""
+from __future__ import annotations
+
 from collections import defaultdict, OrderedDict
 from collections.abc import Mapping
 from functools import lru_cache
@@ -32,6 +34,7 @@ from marshmallow.utils import (
     get_value,
     is_collection,
     is_instance_or_subclass,
+    validate_unknown_parameter_value,
 )
 from marshmallow.warnings import RemovedInMarshmallow4Warning
 
@@ -127,8 +130,8 @@ class SchemaMeta(type):
     def get_declared_fields(
         mcs,
         klass: type,
-        cls_fields: typing.List,
-        inherited_fields: typing.List,
+        cls_fields: list,
+        inherited_fields: list,
         dict_cls: type,
     ):
         """Returns a dictionary of field_name => `Field` pairs declared on the class.
@@ -139,7 +142,7 @@ class SchemaMeta(type):
         :param cls_fields: The fields declared on the class, including those added
             by the ``include`` class Meta option.
         :param inherited_fields: Inherited fields.
-        :param dict_class: Either `dict` or `OrderedDict`, depending on the whether
+        :param dict_cls: Either `dict` or `OrderedDict`, depending on whether
             the user specified `ordered=True`.
         """
         return dict_cls(inherited_fields + cls_fields)
@@ -150,7 +153,7 @@ class SchemaMeta(type):
             class_registry.register(name, cls)
         cls._hooks = cls.resolve_hooks()
 
-    def resolve_hooks(cls) -> typing.Dict[types.Tag, typing.List[str]]:
+    def resolve_hooks(cls) -> dict[types.Tag, list[str]]:
         """Add in the decorated processors
 
         By doing this after constructing the class, we let standard inheritance
@@ -225,7 +228,7 @@ class SchemaOpts:
         self.include = getattr(meta, "include", {})
         self.load_only = getattr(meta, "load_only", ())
         self.dump_only = getattr(meta, "dump_only", ())
-        self.unknown = getattr(meta, "unknown", RAISE)
+        self.unknown = validate_unknown_parameter_value(getattr(meta, "unknown", RAISE))
         self.register = getattr(meta, "register", True)
 
 
@@ -364,14 +367,14 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
     def __init__(
         self,
         *,
-        only: typing.Optional[types.StrSequenceOrSet] = None,
+        only: types.StrSequenceOrSet | None = None,
         exclude: types.StrSequenceOrSet = (),
         many: bool = False,
-        context: typing.Optional[typing.Dict] = None,
+        context: dict | None = None,
         load_only: types.StrSequenceOrSet = (),
         dump_only: types.StrSequenceOrSet = (),
-        partial: typing.Union[bool, types.StrSequenceOrSet] = False,
-        unknown: typing.Optional[str] = None
+        partial: bool | types.StrSequenceOrSet = False,
+        unknown: str | None = None,
     ):
         # Raise error if only or exclude is passed as string, not list of strings
         if only is not None and not is_collection(only):
@@ -387,7 +390,11 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         self.load_only = set(load_only) or set(self.opts.load_only)
         self.dump_only = set(dump_only) or set(self.opts.dump_only)
         self.partial = partial
-        self.unknown = unknown or self.opts.unknown
+        self.unknown = (
+            self.opts.unknown
+            if unknown is None
+            else validate_unknown_parameter_value(unknown)
+        )
         self.context = context or {}
         self._normalize_nested_options()
         #: Dictionary mapping field_names -> :class:`Field` objects
@@ -418,9 +425,9 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
     @classmethod
     def from_dict(
         cls,
-        fields: typing.Dict[str, typing.Union[ma_fields.Field, type]],
+        fields: dict[str, ma_fields.Field | type],
         *,
-        name: str = "GeneratedSchema"
+        name: str = "GeneratedSchema",
     ) -> type:
         """Generate a `Schema` class given a dictionary of fields.
 
@@ -498,9 +505,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
             return error.valid_data or missing
         return value
 
-    def _serialize(
-        self, obj: typing.Union[_T, typing.Iterable[_T]], *, many: bool = False
-    ):
+    def _serialize(self, obj: _T | typing.Iterable[_T], *, many: bool = False):
         """Serialize ``obj``.
 
         :param obj: The object(s) to serialize.
@@ -524,7 +529,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
             ret[key] = value
         return ret
 
-    def dump(self, obj: typing.Any, *, many: typing.Optional[bool] = None):
+    def dump(self, obj: typing.Any, *, many: bool | None = None):
         """Serialize an object to native Python data types according to this
         Schema's fields.
 
@@ -558,9 +563,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
 
         return result
 
-    def dumps(
-        self, obj: typing.Any, *args, many: typing.Optional[bool] = None, **kwargs
-    ):
+    def dumps(self, obj: typing.Any, *args, many: bool | None = None, **kwargs):
         """Same as :meth:`dump`, except return a JSON-encoded string.
 
         :param obj: The object to serialize.
@@ -579,17 +582,17 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
 
     def _deserialize(
         self,
-        data: typing.Union[
-            typing.Mapping[str, typing.Any],
-            typing.Iterable[typing.Mapping[str, typing.Any]],
-        ],
+        data: (
+            typing.Mapping[str, typing.Any]
+            | typing.Iterable[typing.Mapping[str, typing.Any]]
+        ),
         *,
         error_store: ErrorStore,
         many: bool = False,
         partial=False,
         unknown=RAISE,
-        index=None
-    ) -> typing.Union[_T, typing.List[_T]]:
+        index=None,
+    ) -> _T | list[_T]:
         """Deserialize ``data``.
 
         :param dict data: The data to deserialize.
@@ -687,14 +690,14 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
 
     def load(
         self,
-        data: typing.Union[
-            typing.Mapping[str, typing.Any],
-            typing.Iterable[typing.Mapping[str, typing.Any]],
-        ],
+        data: (
+            typing.Mapping[str, typing.Any]
+            | typing.Iterable[typing.Mapping[str, typing.Any]]
+        ),
         *,
-        many: typing.Optional[bool] = None,
-        partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None,
-        unknown: typing.Optional[str] = None
+        many: bool | None = None,
+        partial: bool | types.StrSequenceOrSet | None = None,
+        unknown: str | None = None,
     ):
         """Deserialize a data structure to an object defined by this Schema's fields.
 
@@ -724,10 +727,10 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         self,
         json_data: str,
         *,
-        many: typing.Optional[bool] = None,
-        partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None,
-        unknown: typing.Optional[str] = None,
-        **kwargs
+        many: bool | None = None,
+        partial: bool | types.StrSequenceOrSet | None = None,
+        unknown: str | None = None,
+        **kwargs,
     ):
         """Same as :meth:`load`, except it takes a JSON string as input.
 
@@ -762,7 +765,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         many,
         partial,
         pass_original,
-        index=None
+        index=None,
     ):
         try:
             if pass_original:  # Pass original, raw data (before unmarshalling)
@@ -774,11 +777,14 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
 
     def validate(
         self,
-        data: typing.Mapping,
+        data: (
+            typing.Mapping[str, typing.Any]
+            | typing.Iterable[typing.Mapping[str, typing.Any]]
+        ),
         *,
-        many: typing.Optional[bool] = None,
-        partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None
-    ) -> typing.Dict[str, typing.List[str]]:
+        many: bool | None = None,
+        partial: bool | types.StrSequenceOrSet | None = None,
+    ) -> dict[str, list[str]]:
         """Validate `data` against the schema, returning a dictionary of
         validation errors.
 
@@ -803,15 +809,15 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
 
     def _do_load(
         self,
-        data: typing.Union[
-            typing.Mapping[str, typing.Any],
-            typing.Iterable[typing.Mapping[str, typing.Any]],
-        ],
+        data: (
+            typing.Mapping[str, typing.Any]
+            | typing.Iterable[typing.Mapping[str, typing.Any]]
+        ),
         *,
-        many: typing.Optional[bool] = None,
-        partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None,
-        unknown: typing.Optional[str] = None,
-        postprocess: bool = True
+        many: bool | None = None,
+        partial: bool | types.StrSequenceOrSet | None = None,
+        unknown: str | None = None,
+        postprocess: bool = True,
     ):
         """Deserialize `data`, returning the deserialized result.
         This method is private API.
@@ -830,9 +836,13 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         :return: Deserialized data
         """
         error_store = ErrorStore()
-        errors = {}  # type: typing.Dict[str, typing.List[str]]
+        errors = {}  # type: dict[str, list[str]]
         many = self.many if many is None else bool(many)
-        unknown = unknown or self.unknown
+        unknown = (
+            self.unknown
+            if unknown is None
+            else validate_unknown_parameter_value(unknown)
+        )
         if partial is None:
             partial = self.partial
         # Run preprocessors
@@ -843,9 +853,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
                 )
             except ValidationError as err:
                 errors = err.normalized_messages()
-                result = (
-                    None
-                )  # type: typing.Optional[typing.Union[typing.List, typing.Dict]]
+                result = None  # type: list | dict | None
         else:
             processed_data = data
         if not errors:
@@ -967,7 +975,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
             invalid_fields |= self.exclude - available_field_names
 
         if invalid_fields:
-            message = "Invalid fields for {}: {}.".format(self, invalid_fields)
+            message = f"Invalid fields for {self}: {invalid_fields}."
             raise ValueError(message)
 
         fields_dict = self.dict_class()
@@ -1072,7 +1080,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         *,
         many: bool,
         original_data,
-        partial: typing.Union[bool, types.StrSequenceOrSet]
+        partial: bool | types.StrSequenceOrSet,
     ):
         # This has to invert the order of the dump processors, so run the pass_many
         # processors first.
@@ -1105,9 +1113,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
             except KeyError as error:
                 if field_name in self.declared_fields:
                     continue
-                raise ValueError(
-                    '"{}" field does not exist.'.format(field_name)
-                ) from error
+                raise ValueError(f'"{field_name}" field does not exist.') from error
 
             data_key = (
                 field_obj.data_key if field_obj.data_key is not None else field_name
@@ -1151,8 +1157,8 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         data,
         original_data,
         many: bool,
-        partial: typing.Union[bool, types.StrSequenceOrSet],
-        field_errors: bool = False
+        partial: bool | types.StrSequenceOrSet,
+        field_errors: bool = False,
     ):
         for attr_name in self._hooks[(VALIDATES_SCHEMA, pass_many)]:
             validator = getattr(self, attr_name)
@@ -1194,7 +1200,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         data,
         many: bool,
         original_data=None,
-        **kwargs
+        **kwargs,
     ):
         key = (tag, pass_many)
         for attr_name in self._hooks[key]:
